pub fn perspective(
vertical_fov: f32,
aspect_ratio: f32,
near: f32,
far: f32,
) -> Mat4Expand description
Creates a perspective projection matrix for use with DirectX and WebGPU.
Expects a left-handed Y-up view space input. Outputs NDC with Z in [0, 1] and Y-up.
Panics
Will panic if vertical_fov is not in the range (0, π), if aspect_ratio is
zero, or if near or far are less than or equal to zero, or if near is equal to
far, when glam_assert is enabled.